@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Fog
   module Compute
     class Aliyun < Fog::Service
@@ -10,30 +12,30 @@ module Fog
       ## MODELS
       #
       model_path 'fog/aliyun/models/compute'
-      model       :server
-      collection  :servers
-      model       :image
-      collection  :images
-      model       :eip_address
-      collection  :eip_addresses
-      model       :security_group
-      collection  :security_groups
-      model       :security_group_rule
-      collection  :security_group_rules
-      model       :volume
-      collection  :volumes
-      model       :snapshot
-      collection  :snapshots
-      model       :vpc
-      collection  :vpcs
-      model       :vswitch
-      collection  :vswitches
-      model       :vrouter
-      collection  :vrouters
-      model       :route_table
-      collection  :route_tables
-      model       :route_entry
-      collection  :route_entrys
+      model :server
+      collection :servers
+      model :image
+      collection :images
+      model :eip_address
+      collection :eip_addresses
+      model :security_group
+      collection :security_groups
+      model :security_group_rule
+      collection :security_group_rules
+      model :volume
+      collection :volumes
+      model :snapshot
+      collection :snapshots
+      model :vpc
+      collection :vpcs
+      model :vswitch
+      collection :vswitches
+      model :vrouter
+      collection :vrouters
+      model :route_table
+      collection :route_tables
+      model :route_entry
+      collection :route_entrys
 
       ## REQUESTS
       #
@@ -95,7 +97,13 @@ module Fog
       request :list_vswitchs
       request :modify_vpc
       request :modify_vswitch
-
+      request :list_vpn_gateways
+      request :list_vpn_customergateways
+      request :list_vpn_connections
+      request :create_vpn_customergateway
+      request :create_vpn_connection
+      request :delete_vpn_customergateway
+      request :delete_vpn_connection
       # VRouter
       request :list_vrouters
 
@@ -184,41 +192,43 @@ module Fog
         end
 
         def initialize(options = {})
-          @openstack_username = options[:openstack_username]
-          @openstack_user_domain = options[:openstack_user_domain] || options[:openstack_domain]
-          @openstack_project_domain = options[:openstack_project_domain] || options[:openstack_domain] || 'Default'
-          @openstack_auth_uri = URI.parse(options[:openstack_auth_url])
+          @aliyun_username = options[:aliyun_username]
+          @aliyun_user_domain = options[:aliyun_user_domain] || options[:aliyun_domain]
+          @aliyun_project_domain = options[:aliyun_project_domain] || options[:aliyun_domain] || 'Default'
 
-          @current_tenant = options[:openstack_tenant]
-          @current_tenant_id = options[:openstack_tenant_id]
+          raise ArgumentError, 'Missing required arguments: :aliyun_auth_url' unless options.key?[:aliyun_auth_url]
+          @aliyun_auth_uri = URI.parse(options[:aliyun_auth_url])
+
+          @current_tenant = options[:aliyun_tenant]
+          @current_tenant_id = options[:aliyun_tenant_id]
 
           @auth_token = Fog::Mock.random_base64(64)
           @auth_token_expiration = (Time.now.utc + 86_400).iso8601
 
-          management_url = URI.parse(options[:openstack_auth_url])
+          management_url = URI.parse(@aliyun_auth_url)
           management_url.port = 8774
           management_url.path = '/v1.1/1'
-          @openstack_management_url = management_url.to_s
+          @aliyun_management_url = management_url.to_s
 
-          identity_public_endpoint = URI.parse(options[:openstack_auth_url])
+          identity_public_endpoint = URI.parse(@aliyun_auth_url)
           identity_public_endpoint.port = 5000
-          @openstack_identity_public_endpoint = identity_public_endpoint.to_s
+          @aliyun_identity_public_endpoint = identity_public_endpoint.to_s
         end
 
         def data
-          self.class.data["#{@openstack_username}-#{@current_tenant}"]
+          self.class.data["#{@aliyun_username}-#{@current_tenant}"]
         end
 
         def reset_data
-          self.class.data.delete("#{@openstack_username}-#{@current_tenant}")
+          self.class.data.delete("#{@aliyun_username}-#{@current_tenant}")
         end
 
         def credentials
-          { provider: 'openstack',
-            openstack_auth_url: @openstack_auth_uri.to_s,
-            openstack_auth_token: @auth_token,
-            openstack_management_url: @openstack_management_url,
-            openstack_identity_endpoint: @openstack_identity_public_endpoint }
+          { provider: 'aliyun',
+            aliyun_auth_url: @aliyun_auth_uri.to_s,
+            aliyun_auth_token: @auth_token,
+            aliyun_management_url: @aliyun_management_url,
+            aliyun_identity_endpoint: @aliyun_identity_public_endpoint }
         end
       end
 
@@ -249,11 +259,11 @@ module Fog
 
         def initialize(options = {})
           # initialize the parameters
-          @aliyun_url              = options[:aliyun_url]
-          @aliyun_accesskey_id     = options[:aliyun_accesskey_id]
+          @aliyun_url = options[:aliyun_url]
+          @aliyun_accesskey_id = options[:aliyun_accesskey_id]
           @aliyun_accesskey_secret = options[:aliyun_accesskey_secret]
-          @aliyun_region_id        = options[:aliyun_region_id]
-          @aliyun_zone_id          = options[:aliyun_zone_id]
+          @aliyun_region_id = options[:aliyun_region_id]
+          @aliyun_zone_id = options[:aliyun_zone_id]
 
           # check for the parameters
           missing_credentials = []
@@ -267,17 +277,25 @@ module Fog
           @connection_options = options[:connection_options] || {}
 
           uri = URI.parse(@aliyun_url)
-          @host   = uri.host
-          @path   = uri.path
-          @port   = uri.port
+          @host = uri.host
+          @path = uri.path
+          @port = uri.port
           @scheme = uri.scheme
 
+          vpcuri = URI.parse('https://vpc.aliyuncs.com')
+          @vpchost = vpcuri.host
+          @vpcpath = vpcuri.path
+          @vpcport = vpcuri.port
+          @vpcscheme = vpcuri.scheme
+
           @persistent = options[:persistent] || false
           @connection = Fog::Core::Connection.new("#{@scheme}://#{@host}:#{@port}", @persistent, @connection_options)
+          @VPCconnection = Fog::Core::Connection.new("#{@vpcscheme}://#{@vpchost}:#{@vpcport}", @persistent, @connection_options)
         end
 
         def reload
           @connection.reset
+          @VPCconnection.reset
         end
 
         def request(params)
@@ -295,13 +313,34 @@ module Fog
                     Fog::Compute::Aliyun::NotFound.slurp(error)
                   else
                     error
-              end
+                  end
           end
 
-          if !response.body.empty? && response.get_header('Content-Type') == 'application/json'
-            response.body = Fog::JSON.decode(response.body)
+          response.body = Fog::JSON.decode(response.body) if !response.body.empty? && response.get_header('Content-Type') == 'application/json'
+
+          response
+        end
+
+        def VPCrequest(params)
+          begin
+            response = @VPCconnection.request(params.merge(headers: {
+              'Content-Type' => 'application/json',
+              'Accept' => 'application/json',
+              'X-Auth-Token' => @auth_token
+            }.merge!(params[:headers] || {}),
+                                                           path: "#{@path}/#{params[:path]}",
+                                                           query: params[:query]))
+          rescue Excon::Errors::HTTPStatusError => error
+            raise case error
+                  when Excon::Errors::NotFound
+                    Fog::Compute::Aliyun::NotFound.slurp(error)
+                  else
+                    error
+                  end
           end
 
+          response.body = Fog::JSON.decode(response.body) if !response.body.empty? && response.get_header('Content-Type') == 'application/json'
+
           response
         end
 
@@ -312,6 +351,12 @@ module Fog
           '?Format=JSON&AccessKeyId=' + @aliyun_accesskey_id + '&Action=' + action + '&SignatureMethod=HMAC-SHA1&RegionId=' + @aliyun_region_id + '&SignatureNonce=' + sigNonce + '&SignatureVersion=1.0&Version=2014-05-26&Timestamp=' + urlTimeFormat
         end
 
+        def defaultAliyunVPCUri(action, sigNonce, time)
+          parTimeFormat = time.strftime('%Y-%m-%dT%H:%M:%SZ')
+          urlTimeFormat = URI.encode(parTimeFormat, ':')
+          '?Format=JSON&AccessKeyId=' + @aliyun_accesskey_id + '&Action=' + action + '&SignatureMethod=HMAC-SHA1&RegionId=' + @aliyun_region_id + '&SignatureNonce=' + sigNonce + '&SignatureVersion=1.0&Version=2016-04-28&Timestamp=' + urlTimeFormat
+        end
+
         # generate random num
         def randonStr
           numStr = rand(100_000).to_s
@@ -337,6 +382,22 @@ module Fog
           para
         end
 
+        def defalutVPCParameters(action, sigNonce, time)
+          parTimeFormat = time.strftime('%Y-%m-%dT%H:%M:%SZ')
+          para = {
+            'Format' => 'JSON',
+            'Version' => '2016-04-28',
+            'Action' => action,
+            'AccessKeyId' => @aliyun_accesskey_id,
+            'SignatureVersion' => '1.0',
+            'SignatureMethod' => 'HMAC-SHA1',
+            'SignatureNonce' => sigNonce,
+            'RegionId' => @aliyun_region_id,
+            'Timestamp' => parTimeFormat
+          }
+          para
+        end
+
         # compute signature
         def sign(accessKeySecret, parameters)
           sortedParameters = parameters.sort
@@ -349,8 +410,8 @@ module Fog
           stringToSign = 'GET&%2F&' + URI.encode(canonicalizedQueryString, '/[^!*\'()\;?:@#&%=+$,{}[]<>`" ')
           key = accessKeySecret + '&'
 
-          digVer =  OpenSSL::Digest.new('sha1')
-          digest =  OpenSSL::HMAC.digest(digVer, key, stringToSign)
+          digVer = OpenSSL::Digest.new('sha1')
+          digest = OpenSSL::HMAC.digest(digVer, key, stringToSign)
           signature = Base64.encode64(digest)
           signature[-1] = ''
           encodedSig = URI.encode(signature, '/[^!*\'()\;?:@#&%=+$,{}[]<>`" ')
