@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Fog
   module Compute
     class Aliyun
@@ -35,7 +37,7 @@ module Fog
           end
 
           _InternetChargeType = options[:internet_charge_type]
-          _InternetChargeType = 'PayByTraffic' unless _InternetChargeType
+          _InternetChargeType ||= 'PayByTraffic'
           _parameters['InternetChargeType'] = _InternetChargeType
           _pathURL += '&InternetChargeType=' + _InternetChargeType
 
@@ -49,6 +51,6 @@ module Fog
           )
         end
       end
-    end # aliyun
-  end # compute
+    end
+  end
 end
