@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Fog
   module Compute
     class Aliyun
@@ -36,7 +38,7 @@ module Fog
           end
 
           _PageSize = options[:page_size]
-          _PageSize = '50' unless _PageSize
+          _PageSize ||= '50'
           _parameters['PageSize'] = _PageSize
           _pathURL += '&PageSize=' + _PageSize
 
@@ -50,6 +52,6 @@ module Fog
           )
         end
       end
-    end # aliyun
-  end # compute
+    end
+  end
 end
