@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Fog
   module Compute
     class Aliyun
@@ -30,14 +32,6 @@ module Fog
           )
         end
       end
-
-      class Mock
-        def reboot_server(_server_id, _type = 'SOFT')
-          response = Excon::Response.new
-          response.status = 202
-          response
-        end
-      end
     end
   end
 end
