@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Fog
   module Storage
     class Aliyun
@@ -20,11 +22,6 @@ module Fog
           )
         end
       end
-
-      class Mock
-        def delete_bucket(bucket)
-        end
-      end
     end
   end
 end
