@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Fog
   module Storage
     class Aliyun
@@ -26,10 +28,6 @@ module Fog
           )
         end
       end
-      class Mock
-        def delete_container(container, options = {})
-        end
-      end
     end
   end
 end
