@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Fog
   module Storage
     class Aliyun
@@ -41,7 +43,6 @@ module Fog
           end
 
           location = get_bucket_location(bucket)
-          endpoint = 'http://' + location + '.aliyuncs.com'
           resource = bucket + '/'
           ret = request(
             expects: [200, 203, 400],
@@ -51,12 +52,7 @@ module Fog
             bucket: bucket
           )
           xml = ret.data[:body]
-          result = XmlSimple.xml_in(xml)['CommonPrefixes']
-        end
-      end
-
-      class Mock
-        def get_containers(options = {})
+          XmlSimple.xml_in(xml)['CommonPrefixes']
         end
       end
     end
