@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Fog
   module Storage
     class Aliyun
@@ -19,25 +21,20 @@ module Fog
           acl = get_bucket_acl(bucket)
           location = get_bucket_location(bucket)
 
-          if 'private' == acl
+          if acl == 'private'
             expires_time = (Time.now.to_i + expires).to_s
             resource = bucket + '/' + object
             signature = sign('GET', expires_time, nil, resource)
-            url = 'https://' + bucket + '.' + location + '.aliyuncs.com/' + object +
-                  '?OSSAccessKeyId=' + @aliyun_accesskey_id + '&Expires=' + expires_time +
-                  '&Signature=' + URI.encode(signature, '/[^!*\'()\;?:@#&%=+$,{}[]<>`" ')
-          elsif 'public-read' == acl || 'public-read-write' == acl
-            url = 'https://' + bucket + '.' + location + '.aliyuncs.com/' + object
+            'https://' + bucket + '.' + location + '.aliyuncs.com/' + object +
+              '?OSSAccessKeyId=' + @aliyun_accesskey_id + '&Expires=' + expires_time +
+              '&Signature=' + URI.encode(signature, '/[^!*\'()\;?:@#&%=+$,{}[]<>`" ')
+          elsif acl == 'public-read' || acl == 'public-read-write'
+            'https://' + bucket + '.' + location + '.aliyuncs.com/' + object
           else
-            url = 'acl is wrong with value:' + acl
+            'acl is wrong with value:' + acl
           end
         end
       end
-
-      class Mock
-        def get_object_https_url_public(object, expires, options = {})
-        end
-      end
     end
   end
 end
