@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Fog
   module Storage
     class Aliyun
@@ -24,11 +26,6 @@ module Fog
           ret
         end
       end
-
-      class Mock
-        def head_object(object, options = {})
-        end
-      end
     end
   end
 end
