@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Fog
   module Storage
     class Aliyun
@@ -27,12 +29,7 @@ module Fog
             path: path
           )
           xml = ret.data[:body]
-          result = XmlSimple.xml_in(xml)['Buckets'][0]
-        end
-      end
-
-      class Mock
-        def list_buckets(options = {})
+          XmlSimple.xml_in(xml)['Buckets'][0]
         end
       end
     end
