@@ -1,10 +1,12 @@
+# frozen_string_literal: true
+
 module Fog
   module Storage
     class Aliyun
       class Real
         def put_bucket(bucketName)
           resource = bucketName + '/'
-          ret = request(
+          request(
             expects: [200, 203],
             method: 'PUT',
             resource: resource,
@@ -12,11 +14,6 @@ module Fog
           )
         end
       end
-
-      class Mock
-        def put_bucket(bucketName)
-        end
-      end
     end
   end
 end
