@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Fog
   module Storage
     class Aliyun
@@ -25,11 +27,6 @@ module Fog
           )
         end
       end
-
-      class Mock
-        def put_container(name, options = {})
-        end
-      end
     end
   end
 end
